<?php

namespace CloudPrinterPlugin\Controllers;

use CloudPrinterPlugin\Helpers\CloudPrinterHelper;

/**
 * Class InstallPluginController
 *
 * @copyright   2019 by CloudPrinter
 * @author      Vasyl Kushniruk <vk@cloudprinter.com>
 */
class InstallPluginController
{
    /**
     * @return mixed|void
     */
    public function __construct()
    {
        add_filter('plugin_action_links_' . CP_PLUGIN_BASENAME, array( __CLASS__, 'pluginActionLinks' ));
        register_activation_hook( CP_PLUGIN_FILE, [$this, 'activatePlugin']);
        register_deactivation_hook( CP_PLUGIN_FILE, [$this, 'deactivatePlugin']);
    }

    /**
     * @param $links
     * @return array
     */
    public static function pluginActionLinks($links) {
        $href = admin_url('admin.php?page=cloudprinter');
        $ariaLabel = esc_attr__('View CloudPrinter settings', 'cloudprinter');
        $title = esc_html__('Settings', 'cloudprinter');

        $action_links = [
            'settings' => '<a href="' . $href. '" aria-label="' . $ariaLabel . '">'. $title . '</a>',
        ];

        return array_merge($action_links, $links);
    }

    public function activatePlugin()
    {
        CloudPrinterHelper::webHookSubscribe();
    }

    public function deactivatePlugin()
    {
        $signalId = get_option('cp_signal_id');
        CloudPrinterHelper::webHookUnSubscribe($signalId);
        delete_option('cp_signal_api_key');
    }
}
