<?php

namespace CloudPrinterPlugin\Controllers;

use CloudPrinterPlugin\Helpers\CloudPrinterHelper;
use CloudPrinterPlugin\Models\CPProduct;

/**
 * Class ProductController
 *
 * @copyright   2019 by CloudPrinter
 * @author      Vasyl Kushniruk <vk@cloudprinter.com>
 */
class ProductController
{
    public function __construct()
    {
        // Used to display count pieces for product. In order detail page
        add_filter('woocommerce_product_get_name', [$this, 'changeOrderItemName'], 10, 2);

        // Validation before add product to cart.
        add_filter('woocommerce_add_to_cart_validation', [$this, 'addToCartValidation'], 10, 2);

        // Used to display count pieces for product. in product view page.
        add_action('woocommerce_product_meta_end', [$this, 'displayCountPieces']);

        // Deny adding the product with dynamic options to cart from catalog page.
        add_filter( 'woocommerce_loop_add_to_cart_link', [$this, 'replacingAddToCartButton'], 10, 2 );
    }

    /**
     * Deny adding the product with dynamic options to cart from catalog page.
     */
    public function replacingAddToCartButton($button, $product)
    {
        $cpProduct = new CPProduct($product->get_id());

        if ($cpProduct->hasDynamicOptions()) {
            $button = '<a class="button" href="' . $product->get_permalink() . '">' . $product->add_to_cart_text() . '</a>';
        }

        return $button;
    }

    /**
     * Display count pieces for product. On order detail page.
     */
    public function displayCountPieces()
    {
        global $product;

        $countPieces = $product->get_meta('cp_count_pieces');
        if ($countPieces && $countPieces > 1) {
            echo '<br><span><strong>Pieces:</strong> ' . $countPieces .'</span>';
        }
    }

    /**
     * Validate add product to cart.
     * @param $passed
     * @param $productId
     * @return bool
     */
    public function addToCartValidation($passed, $productId)
    {
        $isPrintProduct = CloudPrinterHelper::isCloudPrinterProduct($productId);
        $apiKey = get_option('cp_api_key');

        if ($isPrintProduct && !$apiKey) {
            wc_add_notice('It`s not possible to add this product to cart, please contact support.', 'error');
            $passed = false;
        }

        return $passed;
    }

    /**
     * Display count pieces for product. On product view page.
     */
    public function changeOrderItemName($realName , $product) {
        $newName = $realName;
        $countPieces = $product->get_meta('cp_count_pieces');
        if (apply_filters('cloudprinter_display_pcs', true) && $countPieces && $countPieces > 1) {
            $newName .= ' (' . $countPieces .' pcs)';
        }

        return apply_filters('cloudprinter_product_get_name', $newName, $realName);
    }
}
