<?php
namespace CloudPrinterPlugin\Models;

use CloudPrinterPlugin\Helpers\CloudPrinterHelper;

/**
 * Class CPOrder
 *
 * @copyright 2019 by CloudPrinter
 * @author    Vasyl Kushniruk <vk@cloudprinter.com>
 */
class CPOrder extends \WC_Order
{
    const STATUS_READY_FOR_POSTING = 'ready_for_posting';
    const STATUS_POSTED = 'posted';
    const STATUS_ERROR = 'error';
    const STATUS_REORDERED = 'reordered';

    /**
     * Get cloudprinter status.
     * @return string
     */
    public function getCPStatus()
    {
        $status = $this->get_meta('_cp_status');

        if (!$status && $this->isRelatedToCloudPrinter()) {
            $status = self::STATUS_READY_FOR_POSTING;
        }

        return $status;
    }

    /**
     * Get html class of cloudprinter status. Use in order list.
     * @return string
     */
    public function getCPStatusHtmlClass()
    {
        $status = $this->getCPStatus();
        switch ($status) {
            case self::STATUS_POSTED:
            case self::STATUS_REORDERED:
                return 'status-completed';
            case self::STATUS_ERROR:
                return 'status-failed';
            case self::STATUS_READY_FOR_POSTING:
                return 'status-on-hold';
        }
    }

    /**
     * Get order cloudprinter reference.
     * @return mixed
     */
    public function getCPOrderReference()
    {
        $status = $this->getCPStatus();
        if ($status && !in_array($status, [self::STATUS_READY_FOR_POSTING, self::STATUS_ERROR])) {
            return $this->get_meta('_cp_order_reference');
        }
    }

    public function isPosted()
    {
        return (bool)$this->get_meta('_cp_order_reference');
    }

    public function isPostingError()
    {
        $status = $this->get_meta('_cp_status');

        return $status == self::STATUS_ERROR;
    }

    /**
     * Check, if order has cloudprinter products.
     * @return bool
     */
    public function isRelatedToCloudPrinter()
    {
        $products = $this->get_items();

        foreach ($products as $product) {
            if (CloudPrinterHelper::isCloudPrinterProduct($product['product_id'])) {
                return true;
            }
        }

        return false;
    }

    /**
     * Get order posting mode.
     * @return mixed
     */
    public function getCPMode()
    {
        return $this->get_meta('_cp_order_mode');
    }

    /**
     * Get the difference between what sales price and cost price was
     */
    public function getProductRevenue()
    {
        $cpOrderPrice = $this->getCloudprinterTotalProductPrice();
        $wcorderprice = $this->get_subtotal();

        return $wcorderprice - $cpOrderPrice;
    }

    /**
     * Get the price the shop-owner pay CP for the order
     */
    public function getCloudprinterTotalProductPrice()
    {
        return (float)$this->get_meta('_cp_order_total_product_price');

    }
}
