<?php

namespace CloudPrinterPlugin\Services\DynamicProduct;

use CloudPrinterPlugin\Services\Storage\DropboxService;
use CloudPrinterPlugin\Services\Storage\LocalService;
use CloudPrinterPlugin\Services\Storage\StorageInterface;

/**
 * Class DynamicProductService
 *
 * @copyright 2020 by CloudPrinter
 * @author    Vasyl Kushniruk <vk@cloudprinter.com>
 */
class DynamicProductService
{
    /**
     * @param $order \WC_Order
     */
    public function requestSharedLinksForOrder($order)
    {
        $dynamicProductData = json_decode($order->get_meta('_cp_dynamic_product'), true);
        $storageService = $this->getStorageService();

        if ($dynamicProductData) {
            foreach ($dynamicProductData as $productId => $fileItems) {
                foreach ($fileItems as $index => $fileItem) {
                    if ($fileItem['storage'] == 'local') {

                        $dynamicProductData[$productId][$index]['shared_link'] = $storageService->getSharedLink($fileItem['file']);
                    }
                }
            }
            update_post_meta($order->get_id(), '_cp_dynamic_product', json_encode($dynamicProductData));
        }
    }

    /**
     * @param $order \WC_Order
     */
    public function revokeSharedLinksForOrder($order)
    {
        $dropboxService = new DropboxService();

        $dynamicProductData = json_decode($order->get_meta('_cp_dynamic_product'), true);

        if ($dynamicProductData) {
            foreach ($dynamicProductData as $productId => &$fileItems) {
                foreach ($fileItems as &$fileItem) {
                    if ($fileItem['storage'] == 'local') {
                        $dropboxService->revokeSharedLink($fileItem['shared_link']);
                        $fileItem['shared_link'] = null;
                    }
                }
            }

            update_post_meta($order->get_id(), '_cp_dynamic_product', json_encode($dynamicProductData));
        }
    }

    /**
     * @param $order \WC_Order
     */
    public function deleteFilesForOrder($order)
    {
        $storage = $this->getStorageService();

        $dynamicProductData = json_decode($order->get_meta('_cp_dynamic_product'), true);

        if ($dynamicProductData) {
            $files = [];
            foreach ($dynamicProductData as $productId => $fileItems) {
                foreach ($fileItems as $key => $fileItem) {
                    if ($fileItem['storage'] == 'local') {
                        $files[] = $fileItem['file'];
                        unset($dynamicProductData[$productId][$key]);
                    }
                }
            }

            $storage->removeFilesFromOrderedFolder($files);

            update_post_meta($order->get_id(), '_cp_dynamic_product', json_encode($dynamicProductData));
        }
    }

    /**
     * @param $order \WC_Order
     */
    public function deleteFilesForOrderProduct($order, $productId)
    {
        $dropboxService = new DropboxService();

        $dynamicProductData = json_decode($order->get_meta('_cp_dynamic_product'), true);

        if (!empty($dynamicProductData[$productId])) {
            $files = [];
            foreach ($dynamicProductData[$productId] as $key => $fileItem) {
                if ($fileItem['storage'] == 'local') {
                    $files[] = $fileItem['file'];
                    unset($dynamicProductData[$productId][$key]);
                }
            }

            $dropboxService->removeFilesFromOrderedFolder($files);

            update_post_meta($order->get_id(), '_cp_dynamic_product', json_encode($dynamicProductData));
        }
    }

    /**
     * @param $order \WC_Order
     */
    public function revokeSharedLinkForOrderProduct($order, $productId)
    {
        $dropboxService = new DropboxService();
        $dynamicProductData = json_decode($order->get_meta('_cp_dynamic_product'), true);

        if ($dynamicProductData) {
            foreach ($dynamicProductData[$productId] as &$fileItem) {
                if ($fileItem['storage'] == 'local') {
                    $dropboxService->revokeSharedLink($fileItem['shared_link']);
                    $fileItem['shared_link'] = null;
                }
            }

            update_post_meta($order->get_id(), '_cp_dynamic_product', json_encode($dynamicProductData));
        }
    }

    public function generateDropboxTemporaryLinksForOrder($orderId)
    {
        $dropboxService = new DropboxService();

        $dynamicProductData = json_decode(get_post_meta($orderId,'_cp_dynamic_product', true), true);
        if ($dynamicProductData) {
            foreach ($dynamicProductData as &$dynamicProductFiles)
            {
                foreach ($dynamicProductFiles as &$dynamicProductFile) {
                    $link  = $dropboxService->getTemporaryLink($dynamicProductFile['file']);
                    $dynamicProductFile['tmp'] = [
                        'link' => $link,
                        'expired_time' => time() + (60 *60 * 4)
                    ];
                }
            }
        }

        update_post_meta($orderId, '_cp_dynamic_product', json_encode($dynamicProductData));
    }

    /**
     * @param null $dynamicProductStorage
     * @return StorageInterface
     */
    public function getStorageService($dynamicProductStorage = null)
    {
        if (is_null($dynamicProductStorage)) {
            $dynamicProductStorage = get_option('cp_dynamic_product_storage', 'local');
        }

        switch ($dynamicProductStorage) {
            case 'dropbox':
                return new DropboxService();
            default:
                return new LocalService();
        }
    }

    public function getStorageServiceName()
    {
       return get_option('cp_dynamic_product_storage', 'local');
    }
}
