<?php

namespace CloudPrinterPlugin\Services\Storage;

/**
 * Class LocalService
 *
 * @copyright 2020 by CloudPrinter
 * @author    Vasyl Kushniruk <vk@cloudprinter.com>
 */
class LocalService implements StorageInterface
{
    /**
     * Dropbox folders.
     */
    const BASE_DIRECTORY = 'cloudprinter';
    const TEMPORARY_FOLDER_NAME = 'uploading';
    const ORDERED_FOLDER_NAME = 'ordered';

    /**
     * @param $fileData array
     * @return string
     */
    public function uploadFileToTemporaryFolder($fileData)
    {
        $fileContent = file_get_contents($fileData['file']['tmp_name']);
        $extension = array_reverse(explode(".", $fileData['file']['name']))[0];
        $newFileName = md5(rand(0, 100000000) + time()).'.' . $extension;
        $newFileDestination = trailingslashit($this->getTemporaryFolderPath() . '/');

        $file_handle = @fopen( trailingslashit( $newFileDestination ) . $newFileName, 'w' );
        if ( $file_handle ) {
            fwrite( $file_handle, $fileContent );
            fclose( $file_handle );
        }

        return $newFileName;
    }

    /**
     * @param $fileData array
     * @return string
     */
    public function uploadFileToOrderedFolder($fileData)
    {
        $fileContent = file_get_contents($fileData['file']['tmp_name']);
        $extension = array_reverse(explode(".", $fileData['file']['name']))[0];
        $newFileName = md5(rand(0, 100000000) + time()).'.' . $extension;
        $newFileDestination = trailingslashit($this->getOrderedFolderPath() . '/');

        $file_handle = @fopen( trailingslashit( $newFileDestination ) . $newFileName, 'w' );
        if ( $file_handle ) {
            fwrite( $file_handle, $fileContent );
            fclose( $file_handle );
        }

        return $newFileName;
    }

    public function moveFilesFromTmpFolderToOrdered($filesNames) {
        foreach ($filesNames as $fileName) {
            $temporaryFileDestination = $this->getTemporaryFolderPath() . '/' . $fileName;
            $orderedFileDestination = $this->getOrderedFolderPath() . '/' . $fileName;

            $fileContent = file_get_contents($temporaryFileDestination);

            $file_handle = @fopen($orderedFileDestination, 'w' );
            if ( $file_handle ) {
                fwrite( $file_handle, $fileContent );
                fclose( $file_handle );
            }
            unlink($temporaryFileDestination);
        }
    }

    public function getSharedLink($fileName)
    {
        $uploadDirInfo = wp_upload_dir();
        return  $uploadDirInfo['baseurl'] . '/' . self::BASE_DIRECTORY . '/' . self::ORDERED_FOLDER_NAME . '/' . $fileName;
    }

    public function removeFileFromTemporaryFolder($fileName)
    {
        $temporaryFileDestination = $this->getTemporaryFolderPath() . '/' . $fileName;

        if (file_exists($temporaryFileDestination)) {
            return unlink($temporaryFileDestination);
        } else {
            return true;
        }
    }

    public function removeFilesFromOrderedFolder($filesNames)
    {
        foreach ($filesNames as $fileName) {
            $orderedFileDestination = $this->getOrderedFolderPath() . '/' . $fileName;
            unlink($orderedFileDestination);
        }
    }

    private function getTemporaryFolderPath()
    {
        $uploadDirInfo = wp_upload_dir();
        $temporaryFolderPath =$uploadDirInfo['basedir'] . '/' . self::BASE_DIRECTORY . '/' . self::TEMPORARY_FOLDER_NAME;

        if (!file_exists($temporaryFolderPath)) {
            mkdir($temporaryFolderPath, 0777, true);
        }

        return $temporaryFolderPath;
    }

    private function getOrderedFolderPath()
    {
        $uploadDirInfo = wp_upload_dir();
        $orderedFolderPath =$uploadDirInfo['basedir'] . '/' . self::BASE_DIRECTORY . '/' . self::ORDERED_FOLDER_NAME;
        mkdir($orderedFolderPath, 0777, true);

        return $orderedFolderPath;
    }

}
